@@ -3,7 +3,7 @@
 # @package      hubzero-expire-sessions
 # @file         expire-sessions.py
 # @author       Rick Kennell <kennell@purdue.edu>
-# @author	John Rosheck <jrosheck@purdue.edu>
+# @author	    John Rosheck <jrosheck@purdue.edu>
 # @copyright    Copyright (c) 2005-2011 Purdue University. All rights reserved.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
@@ -28,18 +28,34 @@
 #
 # HUBzero is a registered trademark of Purdue University.
 
-import os,pwd,sys,time,ldap,MySQLdb,signal
+import os,pwd,sys,time,MySQLdb,signal
 
-# always run in /var/lib/hubzero
-os.chdir("/var/lib/hubzero")
+os.chdir("/")
 
 foreground = 0
 
 expire_interval = 15
-logfile_name = "/var/log/hubzero/expire.log"
+logfile_name = "/var/log/expire-sessions/expire-sessions.log"
 logfile = None
-pidfile = "/var/run/expire-sessions.pid"
-mwprog = "/usr/lib/hubzero/bin/maxwell"
+pidfile = "/var/run/expire-sessions/expire-sessions.pid"
+
+if os.path.exists("/usr/lib/mw/bin/maxwell"):
+  mwprog="/usr/lib/mw/bin/maxwell"
+elif os.path.exists("/usr/lib/hubzero/bin/maxwell"):
+  mwprog="/usr/lib/hubzero/bin/maxwell"
+elif os.path.exists("/usr/bin/maxwell"):
+  mwprog="/usr/bin/maxwell"
+else
+  mwprog=""
+
+if os.path.exists("/etc/mw-www/maxwell.conf"):
+  config_file="/etc/mw-www/maxwell.conf"
+elif os.path.exists("/etc/hubzero/maxwell.conf"):
+  config_file="/etc/hubzero/maxwell.conf"
+elif os.path.exists("/etc/mw/maxwell.conf"):
+  config_file="/etc/mw/maxwell.conf"
+else
+  config_file=""
 
 #==============================================================================
 # Default values.
@@ -55,7 +71,7 @@ mysql_connect_attempts=120
 # Load the configuration and override the variables above.
 #=============================================================================
 try:
-  execfile('/etc/hubzero/maxwell.conf')
+  execfile(config_file)
 except IOError:
   pass
 
